@@ -1,6 +1,6 @@
 
 
-.cpp_funs <- c("sum", "mean", "median", "modal", "which", "which.min", "which.max", "min", "max", "prod", "any", "all", "sd", "std", "first")
+.cpp_funs <- c("sum", "mean", "median", "modal", "which", "which.min", "which.max", "min", "max", "prod", "any", "all", "none", "sd", "std", "first")
 
 setMethod("sapp", signature(x="SpatRaster"),
 function(x, fun, ..., filename="", overwrite=FALSE, wopt=list())  {
@@ -60,7 +60,7 @@ function(x, fun, ..., cores=1, filename="", overwrite=FALSE, wopt=list())  {
 		if (txtfun %in% .cpp_funs) {
 			opt <- spatOptions(filename, overwrite, wopt=wopt)
 			na.rm <- isTRUE(list(...)$na.rm)
-			x@ptr <- x@ptr$summary(txtfun, na.rm, opt)
+			x@pntr <- x@pntr$summary(txtfun, na.rm, opt)
 			return(messages(x, "app"))
 		}
 	}
@@ -277,7 +277,7 @@ function(x, fun, ..., cores=1, filename="", overwrite=FALSE, wopt=list())  {
 			opt <- spatOptions(filename, overwrite, wopt=wopt)
 			narm <- isTRUE(list(...)$na.rm)
 			r <- rast()
-			r@ptr <- x@ptr$summary(txtfun, narm, opt)
+			r@pntr <- x@pntr$summary(txtfun, narm, opt)
 			return (messages(r, "app") )
 		}
 	}
