@@ -1,6 +1,6 @@
 
 setMethod("cartogram", signature(x="SpatVector"),
-	function(x, var, type="nc")  {
+	function(x, var, type="nc", inside=FALSE, exp=1)  {
 		if (geomtype(x) != "polygons") {
 			error("cartogram", "x must be polygons")
 		}
@@ -19,18 +19,23 @@ setMethod("cartogram", signature(x="SpatVector"),
 		if (nrow(x) == 0) return(vect("POLYGON EMPTY"))
 
 		f <- v / max(v)
-		cntrds <- centroids(x, inside=TRUE)
-		cxy <- crds(cntrds)
-		r <- lapply(1:length(v), function(i) {
-			rescale(x[i,], f[i], x0=cxy[i,1], y0=cxy[i,2])
-		})
-		out <- do.call(rbind, r)
-		
+		if (exp <= 0) exp <- 1
+		exp <- sqrt(exp)
+		cntrds <- centroids(x, inside=inside)
 		if (type == "circles") {
-			out <- buffer(cntrds, width(out)/2)
+			w <- max(width(buffer(cntrds, width(x))))
+			ff <- exp * (sqrt(f / pi) * w/4)
+			buffer(cntrds, ff)
+		} else {
+			cxy <- crds(cntrds)
+			s <- sqrt(expanse(x))
+			ff <- s[which.max(f)] / s
+			ff <- ff * sqrt(f) * exp
+			r <- lapply(1:length(v), function(i) {
+				rescale(x[i,], ff[i], x0=cxy[i,1], y0=cxy[i,2])
+			})
+			b = do.call(rbind, r)
 		}
-		
-		out
 	}
 )
 
