@@ -571,8 +571,6 @@ bool layerQueryFilter(GDALDataset *&poDS, OGRLayer *&poLayer, std::string &layer
 
 
 
-
-
 bool SpatVector::read_ogr(GDALDataset *&poDS, std::string layer, std::string query, std::vector<double> ext, SpatVector filter, bool as_proxy, std::string what, std::string dialect) {
 
 	if (poDS == NULL) {
@@ -673,15 +671,16 @@ bool SpatVector::read_ogr(GDALDataset *&poDS, std::string layer, std::string que
 			}
 			addGeom(g);
 			OGRFeature::DestroyFeature( poFeature );
-		} else if ( wkbgeom == wkbPolygon || wkbgeom == wkbMultiPolygon) {
+		} else if ((wkbgeom == wkbPolygon) || (wkbgeom == wkbMultiPolygon) ||
+					(wkbgeom == wkbSurface) || (wkbgeom == wkbMultiSurface)) {
 			OGRGeometry *poGeometry = poFeature->GetGeometryRef();
 			if (poGeometry != NULL) {
 				wkbgeom = wkbFlatten(poGeometry->getGeometryType());
 				if (wkbgeom == wkbPolygon) {
 					g = getPolygonsGeom(poGeometry);
-				} else if (wkbgeom == wkbMultiPolygon ) {
+				} else { //if (wkbgeom == wkbMultiPolygon ) {
 					g = getMultiPolygonsGeom(poGeometry);
-				} // else ?
+				} 
 			} else {
 				g = emptyGeom();
 			}
@@ -764,14 +763,15 @@ bool SpatVector::read_ogr(GDALDataset *&poDS, std::string layer, std::string que
 			addGeom(g);
 			OGRFeature::DestroyFeature( poFeature );
 		}
-	} else if ( wkbgeom == wkbPolygon || wkbgeom == wkbMultiPolygon) {
+	} else if ((wkbgeom == wkbPolygon) || (wkbgeom == wkbMultiPolygon) || 
+				(wkbgeom == wkbSurface) || (wkbgeom == wkbMultiSurface)) {
 		while ( (poFeature = poLayer->GetNextFeature()) != NULL ) {
 			OGRGeometry *poGeometry = poFeature->GetGeometryRef();
 			if (poGeometry != NULL) {
 				wkbgeom = wkbFlatten(poGeometry->getGeometryType());
 				if (wkbgeom == wkbPolygon) {
 					g = getPolygonsGeom(poGeometry);
-				} else if (wkbgeom == wkbMultiPolygon ) {
+				} else { //if (wkbgeom == wkbMultiPolygon ) {
 					g = getMultiPolygonsGeom(poGeometry);
 				}
 			} else {
